{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Rewriting.Curry_Term
  ( C_VarIdx, C_TermEq, C_TermEqs, C_Pos, C_Term (..) )
  where

import Basics
import qualified Curry_Prelude


type C_VarIdx = Curry_Prelude.C_Int

type C_TermEq t0 = Curry_Prelude.OP_Tuple2 (C_Term t0) (C_Term t0)

type C_TermEqs t0 = Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_Term t0)
  (C_Term t0))

type C_Pos = Curry_Prelude.OP_List Curry_Prelude.C_Int

data C_Term t0
  = C_TermVar Curry_Prelude.C_Int
  | C_TermCons t0 (Curry_Prelude.OP_List (C_Term t0))
  | Choice_C_Term Cover ID (C_Term t0) (C_Term t0)
  | Choices_C_Term Cover ID [C_Term t0]
  | Fail_C_Term Cover FailInfo
  | Guard_C_Term Cover Constraints (C_Term t0)

instance (Show t0) => Show (C_Term t0) where
  showsPrec d (Choice_C_Term cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_Term cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_Term cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_Term cd info) = showChar '!'
  showsPrec _ (C_TermVar x1) = showString "(TermVar" . (showChar ' ' . (shows
    x1 . showChar ')'))
  showsPrec _ (C_TermCons x1 x2) = showString "(TermCons" . (showChar ' ' .
    (shows x1 . (showChar ' ' . (shows x2 . showChar ')'))))

instance (Read t0) => Read (C_Term t0) where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_TermVar x1, r1) | (_, r0) <-
    readQualified "Rewriting.Term" "TermVar" r, (x1, r1) <- readsPrec 11 r0])
    s ++ readParen ((>) d 10) (\r -> [(C_TermCons x1 x2, r2) | (_, r0) <-
    readQualified "Rewriting.Term" "TermCons" r, (x1, r1) <- readsPrec 11 r0,
    (x2, r2) <- readsPrec 11 r1]) s

instance NonDet (C_Term t0) where
  choiceCons = Choice_C_Term
  choicesCons = Choices_C_Term
  failCons = Fail_C_Term
  guardCons = Guard_C_Term
  try (Choice_C_Term cd i x y) = tryChoice cd i x y
  try (Choices_C_Term cd i xs) = tryChoices cd i xs
  try (Fail_C_Term cd info) = Fail cd info
  try (Guard_C_Term cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_Term cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_Term cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_Term cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_Term cd i _) = error
    ("Rewriting.Term.Term.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_Term cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_Term cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance (Generable t0) => Generable (C_Term t0) where
  generate s c = Choices_C_Term c (freeID [1, 2] s) [C_TermVar (generate
    (leftSupply s) c), C_TermCons (generate (leftSupply s) c) (generate
    (rightSupply s) c)]

instance (NormalForm t0) => NormalForm (C_Term t0) where
  ($!!) cont (C_TermVar x1) d cs = ($!!) (\y1 d cs -> cont (C_TermVar y1) d cs)
    x1 d cs
  ($!!) cont (C_TermCons x1 x2) d cs = ($!!) (\y1 d cs -> ($!!) (\y2 d cs ->
    cont (C_TermCons y1 y2) d cs) x2 d cs) x1 d cs
  ($!!) cont (Choice_C_Term cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_Term cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_Term cd c e) d cs = guardCons cd c (($!!) cont e d (addCs
    c cs))
  ($!!) _ (Fail_C_Term cd info) _ _ = failCons cd info
  ($##) cont (C_TermVar x1) d cs = ($##) (\y1 d cs -> cont (C_TermVar y1) d cs)
    x1 d cs
  ($##) cont (C_TermCons x1 x2) d cs = ($##) (\y1 d cs -> ($##) (\y2 d cs ->
    cont (C_TermCons y1 y2) d cs) x2 d cs) x1 d cs
  ($##) cont (Choice_C_Term cd i x y) d cs = gnfChoice cont cd i x y cd cs
  ($##) cont (Choices_C_Term cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_Term cd c e) d cs = guardCons cd c (($##) cont e d (addCs
    c cs))
  ($##) _ (Fail_C_Term cd info) _ _ = failCons cd info
  showCons (C_TermVar _) = "Rewriting.Term.TermVar _"
  showCons (C_TermCons _ _) = "Rewriting.Term.TermCons _ _"
  showCons x = error ("Rewriting.Term.Term.showCons: no constructor: " ++ show
    x)
  searchNF search cont (C_TermVar x1) = search (\y1 -> cont (C_TermVar y1)) x1
  searchNF search cont (C_TermCons x1 x2) = search (\y1 -> search (\y2 -> cont
    (C_TermCons y1 y2)) x2) x1
  searchNF _ _ x = error ("Rewriting.Term.Term.searchNF: no constructor: " ++
    show x)

instance (Unifiable t0) => Unifiable (C_Term t0) where
  (=.=) (C_TermVar x1) (C_TermVar y1) d cs = (=:=) x1 y1 d cs
  (=.=) (C_TermCons x1 x2) (C_TermCons y1 y2) d cs = (&) ((=:=) x1 y1 d cs)
    ((=:=) x2 y2 d cs) d cs
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_TermVar x1) (C_TermVar y1) d cs = (=:<=) x1 y1 d cs
  (=.<=) (C_TermCons x1 x2) (C_TermCons y1 y2) d cs = (&) ((=:<=) x1 y1 d cs)
    ((=:<=) x2 y2 d cs) d cs
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i (C_TermVar x3) = (i :=: ChooseN 0 1) : concat [bind cd (leftID i)
    x3]
  bind cd i (C_TermCons x3 x4) = (i :=: ChooseN 1 2) : concat [bind cd (leftID
    i) x3, bind cd (rightID i) x4]
  bind d i (Choice_C_Term cd j x y) = [ConstraintChoice cd j (bind d i x) (bind
    d i y)]
  bind d i (Choices_C_Term cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j xs
  bind d i (Choices_C_Term cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd j
    (map (bind d i) xs)]
  bind _ _ (Choices_C_Term cd i _) = error
    ("Rewriting.Term.Term.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_Term cd info) = [Unsolvable info]
  bind d i (Guard_C_Term cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_TermVar x3) = (i :=: ChooseN 0 1) : [leftID i :=: LazyBind
    (lazyBind cd (leftID i) x3)]
  lazyBind cd i (C_TermCons x3 x4) = (i :=: ChooseN 1 2) : [leftID i :=:
    LazyBind (lazyBind cd (leftID i) x3), rightID i :=: LazyBind (lazyBind cd
    (rightID i) x4)]
  lazyBind d i (Choice_C_Term cd j x y) = [ConstraintChoice cd j (lazyBind d i
    x) (lazyBind d i y)]
  lazyBind d i (Choices_C_Term cd j@(FreeID _ _) xs) = lazyBindOrNarrow d i cd j
    xs
  lazyBind d i (Choices_C_Term cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd
    j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_Term cd i _) = error
    ("Rewriting.Term.Term.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_Term cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_Term cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance (Curry t0) => Curry (C_Term t0) where
  (=?=) (Choice_C_Term cd i x y) z d cs = narrow cd i ((=?=) x z d cs) ((=?=) y
    z d cs)
  (=?=) (Choices_C_Term cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x y d cs)
    xs
  (=?=) (Guard_C_Term cd c e) y d cs = guardCons cd c ((=?=) e y d (addCs c cs))
  (=?=) (Fail_C_Term cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_Term cd i x y) d cs = narrow cd i ((=?=) z x d cs) ((=?=) z
    y d cs)
  (=?=) y (Choices_C_Term cd i xs) d cs = narrows cs cd i (\x -> (=?=) y x d cs)
    xs
  (=?=) y (Guard_C_Term cd c e) d cs = guardCons cd c ((=?=) y e d (addCs c cs))
  (=?=) _ (Fail_C_Term cd info) _ _ = failCons cd info
  (=?=) (C_TermVar x1) (C_TermVar y1) d cs = (=?=) x1 y1 d cs
  (=?=) (C_TermCons x1 x2) (C_TermCons y1 y2) d cs = Curry_Prelude.d_OP_amp_amp
    ((=?=) x1 y1 d cs) ((=?=) x2 y2 d cs) d cs
  (=?=) _ _ d _ = C_False
  (<?=) (Choice_C_Term cd i x y) z d cs = narrow cd i ((<?=) x z d cs) ((<?=) y
    z d cs)
  (<?=) (Choices_C_Term cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x y d cs)
    xs
  (<?=) (Guard_C_Term cd c e) y d cs = guardCons cd c ((<?=) e y d (addCs c cs))
  (<?=) (Fail_C_Term cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_Term cd i x y) d cs = narrow cd i ((<?=) z x d cs) ((<?=) z
    y d cs)
  (<?=) y (Choices_C_Term cd i xs) d cs = narrows cs cd i (\x -> (<?=) y x d cs)
    xs
  (<?=) y (Guard_C_Term cd c e) d cs = guardCons cd c ((<?=) y e d (addCs c cs))
  (<?=) _ (Fail_C_Term cd info) _ _ = failCons cd info
  (<?=) (C_TermVar x1) (C_TermVar y1) d cs = (<?=) x1 y1 d cs
  (<?=) (C_TermVar _) (C_TermCons _ _) _ _ = C_True
  (<?=) (C_TermCons x1 x2) (C_TermCons y1 y2) d cs = Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_lt x1 y1 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1
    d cs) ((<?=) x2 y2 d cs) d cs) d cs
  (<?=) _ _ d _ = C_False

