{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Rewriting.Curry_Unification ( C_RTerm (..), d_C_unify, nd_C_unify ) where

import Basics
import qualified Curry_FiniteMap
import qualified Curry_List
import qualified Curry_Prelude
import qualified Rewriting.Curry_Substitution
import qualified Rewriting.Curry_Term
import qualified Rewriting.Curry_UnificationSpec


type C_RefTable t0 = Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)

type C_REq t0 = Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)

type C_REqs t0 = Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))

data C_RTerm t0
  = C_RTermCons t0 (Curry_Prelude.OP_List (C_RTerm t0))
  | C_RTermVar Curry_Prelude.C_Int
  | C_Ref Curry_Prelude.C_Int
  | Choice_C_RTerm Cover ID (C_RTerm t0) (C_RTerm t0)
  | Choices_C_RTerm Cover ID [C_RTerm t0]
  | Fail_C_RTerm Cover FailInfo
  | Guard_C_RTerm Cover Constraints (C_RTerm t0)

instance (Show t0) => Show (C_RTerm t0) where
  showsPrec d (Choice_C_RTerm cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_RTerm cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_RTerm cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_RTerm cd info) = showChar '!'
  showsPrec _ (C_RTermCons x1 x2) = showString "(RTermCons" . (showChar ' ' .
    (shows x1 . (showChar ' ' . (shows x2 . showChar ')'))))
  showsPrec _ (C_RTermVar x1) = showString "(RTermVar" . (showChar ' ' . (shows
    x1 . showChar ')'))
  showsPrec _ (C_Ref x1) = showString "(Ref" . (showChar ' ' . (shows x1 .
    showChar ')'))

instance (Read t0) => Read (C_RTerm t0) where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_RTermCons x1 x2, r2) | (_, r0)
    <- readQualified "Rewriting.Unification" "RTermCons" r, (x1, r1) <-
    readsPrec 11 r0, (x2, r2) <- readsPrec 11 r1]) s ++ (readParen ((>) d 10)
    (\r -> [(C_RTermVar x1, r1) | (_, r0) <- readQualified
    "Rewriting.Unification" "RTermVar" r, (x1, r1) <- readsPrec 11 r0]) s ++
    readParen ((>) d 10) (\r -> [(C_Ref x1, r1) | (_, r0) <- readQualified
    "Rewriting.Unification" "Ref" r, (x1, r1) <- readsPrec 11 r0]) s)

instance NonDet (C_RTerm t0) where
  choiceCons = Choice_C_RTerm
  choicesCons = Choices_C_RTerm
  failCons = Fail_C_RTerm
  guardCons = Guard_C_RTerm
  try (Choice_C_RTerm cd i x y) = tryChoice cd i x y
  try (Choices_C_RTerm cd i xs) = tryChoices cd i xs
  try (Fail_C_RTerm cd info) = Fail cd info
  try (Guard_C_RTerm cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_RTerm cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_RTerm cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_RTerm cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_RTerm cd i _) = error
    ("Rewriting.Unification.RTerm.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_RTerm cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_RTerm cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance (Generable t0) => Generable (C_RTerm t0) where
  generate s c = Choices_C_RTerm c (freeID [2, 1, 1] s) [C_RTermCons (generate
    (leftSupply s) c) (generate (rightSupply s) c), C_RTermVar (generate
    (leftSupply s) c), C_Ref (generate (leftSupply s) c)]

instance (NormalForm t0) => NormalForm (C_RTerm t0) where
  ($!!) cont (C_RTermCons x1 x2) d cs = ($!!) (\y1 d cs -> ($!!) (\y2 d cs ->
    cont (C_RTermCons y1 y2) d cs) x2 d cs) x1 d cs
  ($!!) cont (C_RTermVar x1) d cs = ($!!) (\y1 d cs -> cont (C_RTermVar y1) d
    cs) x1 d cs
  ($!!) cont (C_Ref x1) d cs = ($!!) (\y1 d cs -> cont (C_Ref y1) d cs) x1 d cs
  ($!!) cont (Choice_C_RTerm cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_RTerm cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_RTerm cd c e) d cs = guardCons cd c (($!!) cont e d (addCs
    c cs))
  ($!!) _ (Fail_C_RTerm cd info) _ _ = failCons cd info
  ($##) cont (C_RTermCons x1 x2) d cs = ($##) (\y1 d cs -> ($##) (\y2 d cs ->
    cont (C_RTermCons y1 y2) d cs) x2 d cs) x1 d cs
  ($##) cont (C_RTermVar x1) d cs = ($##) (\y1 d cs -> cont (C_RTermVar y1) d
    cs) x1 d cs
  ($##) cont (C_Ref x1) d cs = ($##) (\y1 d cs -> cont (C_Ref y1) d cs) x1 d cs
  ($##) cont (Choice_C_RTerm cd i x y) d cs = gnfChoice cont cd i x y cd cs
  ($##) cont (Choices_C_RTerm cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_RTerm cd c e) d cs = guardCons cd c (($##) cont e d (addCs
    c cs))
  ($##) _ (Fail_C_RTerm cd info) _ _ = failCons cd info
  showCons (C_RTermCons _ _) = "Rewriting.Unification.RTermCons _ _"
  showCons (C_RTermVar _) = "Rewriting.Unification.RTermVar _"
  showCons (C_Ref _) = "Rewriting.Unification.Ref _"
  showCons x = error
    ("Rewriting.Unification.RTerm.showCons: no constructor: " ++ show x)
  searchNF search cont (C_RTermCons x1 x2) = search (\y1 -> search (\y2 -> cont
    (C_RTermCons y1 y2)) x2) x1
  searchNF search cont (C_RTermVar x1) = search (\y1 -> cont (C_RTermVar y1)) x1
  searchNF search cont (C_Ref x1) = search (\y1 -> cont (C_Ref y1)) x1
  searchNF _ _ x = error
    ("Rewriting.Unification.RTerm.searchNF: no constructor: " ++ show x)

instance (Unifiable t0) => Unifiable (C_RTerm t0) where
  (=.=) (C_RTermCons x1 x2) (C_RTermCons y1 y2) d cs = (&) ((=:=) x1 y1 d cs)
    ((=:=) x2 y2 d cs) d cs
  (=.=) (C_RTermVar x1) (C_RTermVar y1) d cs = (=:=) x1 y1 d cs
  (=.=) (C_Ref x1) (C_Ref y1) d cs = (=:=) x1 y1 d cs
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_RTermCons x1 x2) (C_RTermCons y1 y2) d cs = (&) ((=:<=) x1 y1 d cs)
    ((=:<=) x2 y2 d cs) d cs
  (=.<=) (C_RTermVar x1) (C_RTermVar y1) d cs = (=:<=) x1 y1 d cs
  (=.<=) (C_Ref x1) (C_Ref y1) d cs = (=:<=) x1 y1 d cs
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i (C_RTermCons x3 x4) = (i :=: ChooseN 0 2) : concat [bind cd (leftID
    i) x3, bind cd (rightID i) x4]
  bind cd i (C_RTermVar x3) = (i :=: ChooseN 1 1) : concat [bind cd (leftID i)
    x3]
  bind cd i (C_Ref x3) = (i :=: ChooseN 2 1) : concat [bind cd (leftID i) x3]
  bind d i (Choice_C_RTerm cd j x y) = [ConstraintChoice cd j (bind d i x) (bind
    d i y)]
  bind d i (Choices_C_RTerm cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j xs
  bind d i (Choices_C_RTerm cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd j
    (map (bind d i) xs)]
  bind _ _ (Choices_C_RTerm cd i _) = error
    ("Rewriting.Unification.RTerm.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_RTerm cd info) = [Unsolvable info]
  bind d i (Guard_C_RTerm cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_RTermCons x3 x4) = (i :=: ChooseN 0 2) : [leftID i :=:
    LazyBind (lazyBind cd (leftID i) x3), rightID i :=: LazyBind (lazyBind cd
    (rightID i) x4)]
  lazyBind cd i (C_RTermVar x3) = (i :=: ChooseN 1 1) : [leftID i :=: LazyBind
    (lazyBind cd (leftID i) x3)]
  lazyBind cd i (C_Ref x3) = (i :=: ChooseN 2 1) : [leftID i :=: LazyBind
    (lazyBind cd (leftID i) x3)]
  lazyBind d i (Choice_C_RTerm cd j x y) = [ConstraintChoice cd j (lazyBind d i
    x) (lazyBind d i y)]
  lazyBind d i (Choices_C_RTerm cd j@(FreeID _ _) xs) = lazyBindOrNarrow d i cd
    j xs
  lazyBind d i (Choices_C_RTerm cd j@(NarrowedID _ _) xs) = [ConstraintChoices
    cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_RTerm cd i _) = error
    ("Rewriting.Unification.RTerm.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_RTerm cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_RTerm cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance (Curry t0) => Curry (C_RTerm t0) where
  (=?=) (Choice_C_RTerm cd i x y) z d cs = narrow cd i ((=?=) x z d cs) ((=?=) y
    z d cs)
  (=?=) (Choices_C_RTerm cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x y d
    cs) xs
  (=?=) (Guard_C_RTerm cd c e) y d cs = guardCons cd c ((=?=) e y d (addCs c
    cs))
  (=?=) (Fail_C_RTerm cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_RTerm cd i x y) d cs = narrow cd i ((=?=) z x d cs) ((=?=) z
    y d cs)
  (=?=) y (Choices_C_RTerm cd i xs) d cs = narrows cs cd i (\x -> (=?=) y x d
    cs) xs
  (=?=) y (Guard_C_RTerm cd c e) d cs = guardCons cd c ((=?=) y e d (addCs c
    cs))
  (=?=) _ (Fail_C_RTerm cd info) _ _ = failCons cd info
  (=?=) (C_RTermCons x1 x2) (C_RTermCons y1 y2) d cs =
    Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) ((=?=) x2 y2 d cs) d cs
  (=?=) (C_RTermVar x1) (C_RTermVar y1) d cs = (=?=) x1 y1 d cs
  (=?=) (C_Ref x1) (C_Ref y1) d cs = (=?=) x1 y1 d cs
  (=?=) _ _ d _ = C_False
  (<?=) (Choice_C_RTerm cd i x y) z d cs = narrow cd i ((<?=) x z d cs) ((<?=) y
    z d cs)
  (<?=) (Choices_C_RTerm cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x y d
    cs) xs
  (<?=) (Guard_C_RTerm cd c e) y d cs = guardCons cd c ((<?=) e y d (addCs c
    cs))
  (<?=) (Fail_C_RTerm cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_RTerm cd i x y) d cs = narrow cd i ((<?=) z x d cs) ((<?=) z
    y d cs)
  (<?=) y (Choices_C_RTerm cd i xs) d cs = narrows cs cd i (\x -> (<?=) y x d
    cs) xs
  (<?=) y (Guard_C_RTerm cd c e) d cs = guardCons cd c ((<?=) y e d (addCs c
    cs))
  (<?=) _ (Fail_C_RTerm cd info) _ _ = failCons cd info
  (<?=) (C_RTermCons x1 x2) (C_RTermCons y1 y2) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) ((<?=) x2 y2 d cs) d cs) d cs
  (<?=) (C_RTermCons _ _) (C_RTermVar _) _ _ = C_True
  (<?=) (C_RTermCons _ _) (C_Ref _) _ _ = C_True
  (<?=) (C_RTermVar x1) (C_RTermVar y1) d cs = (<?=) x1 y1 d cs
  (<?=) (C_RTermVar _) (C_Ref _) _ _ = C_True
  (<?=) (C_Ref x1) (C_Ref y1) d cs = (<?=) x1 y1 d cs
  (<?=) _ _ d _ = C_False

d_C_unify :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Rewriting.Curry_Term.C_Term t0)
  (Rewriting.Curry_Term.C_Term t0)) -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term
  t0))
d_C_unify x1 cd cs = let x2 = d_C_termEqsToREqs x1 cd cs
                         x3 = d_OP_unify_dot_uscore_hash_selFP2_hash_r x2 cd cs
                         x4 = d_OP_unify_dot_uscore_hash_selFP3_hash_rts x2 cd
                           cs
  in d_C__case_18 x4 x3 (d_C_unify' x3 Curry_Prelude.OP_List x4 cd cs) cd cs

nd_C_unify :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Rewriting.Curry_Term.C_Term t0)
  (Rewriting.Curry_Term.C_Term t0)) -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term
  t0))
nd_C_unify x1 s cd cs = let s6 = s
  in s6 `seq` (let s7 = leftSupply s6
                   s8 = rightSupply s6
                   s0 = leftSupply s7
                   s1 = rightSupply s7
                   s2 = leftSupply s8
                   s5 = rightSupply s8
  in s7 `seq` (s8 `seq` (s0 `seq` (s1 `seq` (s2 `seq` (s5 `seq`
  (let x2 = nd_C_termEqsToREqs x1 s0 cd cs
       x3 = nd_OP_unify_dot_uscore_hash_selFP2_hash_r x2 s1 cd cs
       x4 = nd_OP_unify_dot_uscore_hash_selFP3_hash_rts x2 s2 cd cs
  in let s4 = leftSupply s5
         s3 = rightSupply s5
  in s4 `seq` (s3 `seq` nd_C__case_18 x4 x3 (nd_C_unify' x3
  Curry_Prelude.OP_List x4 s3 cd cs) s4 cd cs))))))))

d_OP_unify_dot_uscore_hash_selFP2_hash_r :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))) -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)
d_OP_unify_dot_uscore_hash_selFP2_hash_r x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_unify_dot_uscore_hash_selFP2_hash_r l cd cs)
    (d_OP_unify_dot_uscore_hash_selFP2_hash_r r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_unify_dot_uscore_hash_selFP2_hash_r z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_unify_dot_uscore_hash_selFP2_hash_r e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.unify._#selFP2#r" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify._#selFP2#r" (showCons
    x1))

nd_OP_unify_dot_uscore_hash_selFP2_hash_r :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))) -> IDSupply -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)
nd_OP_unify_dot_uscore_hash_selFP2_hash_r x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_unify_dot_uscore_hash_selFP2_hash_r l s cd cs)
    (nd_OP_unify_dot_uscore_hash_selFP2_hash_r r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_unify_dot_uscore_hash_selFP2_hash_r z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_unify_dot_uscore_hash_selFP2_hash_r e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.unify._#selFP2#r" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify._#selFP2#r" (showCons
    x1))

d_OP_unify_dot_uscore_hash_selFP3_hash_rts :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
d_OP_unify_dot_uscore_hash_selFP3_hash_rts x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_unify_dot_uscore_hash_selFP3_hash_rts l cd cs)
    (d_OP_unify_dot_uscore_hash_selFP3_hash_rts r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_unify_dot_uscore_hash_selFP3_hash_rts z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_unify_dot_uscore_hash_selFP3_hash_rts e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.unify._#selFP3#rts" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify._#selFP3#rts"
    (showCons x1))

nd_OP_unify_dot_uscore_hash_selFP3_hash_rts :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))) -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
nd_OP_unify_dot_uscore_hash_selFP3_hash_rts x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_unify_dot_uscore_hash_selFP3_hash_rts l s cd cs)
    (nd_OP_unify_dot_uscore_hash_selFP3_hash_rts r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_unify_dot_uscore_hash_selFP3_hash_rts z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_unify_dot_uscore_hash_selFP3_hash_rts e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.unify._#selFP3#rts" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify._#selFP3#rts"
    (showCons x1))

d_C_termEqsToREqs :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Rewriting.Curry_Term.C_Term t0) (Rewriting.Curry_Term.C_Term t0)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)))
d_C_termEqsToREqs x1 cd cs = Curry_List.d_C_mapAccumL (acceptCs id
  d_C_termEqToREq) (Curry_FiniteMap.d_C_emptyFM (acceptCs id
  Curry_Prelude.d_OP_lt) cd cs) x1 cd cs

nd_C_termEqsToREqs :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Rewriting.Curry_Term.C_Term t0) (Rewriting.Curry_Term.C_Term t0)) -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)))
nd_C_termEqsToREqs x1 s cd cs = let s2 = s
  in s2 `seq` (let s1 = leftSupply s2
                   s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_List.nd_C_mapAccumL (wrapDX (wrapNX id) (acceptCs
  id nd_C_termEqToREq)) (Curry_FiniteMap.nd_C_emptyFM (wrapDX (wrapDX id)
  (acceptCs id Curry_Prelude.d_OP_lt)) s0 cd cs) x1 s1 cd cs))

d_C_termEqToREq :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_Tuple2
  (Rewriting.Curry_Term.C_Term t0) (Rewriting.Curry_Term.C_Term t0) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))
d_C_termEqToREq x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> let x5 = d_C_termToRTerm x1 x3 cd cs
                                       x6 = d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1
                                         x5 cd cs
                                       x7 = d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick
                                         x5 cd cs
                                       x8 = d_C_termToRTerm x6 x4 cd cs
                                       x9 = d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2
                                         x8 cd cs
                                       x10 = d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick
                                         x8 cd cs
    in Curry_Prelude.OP_Tuple2 x9 (Curry_Prelude.OP_Tuple2 x7 x10)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_termEqToREq x1 l cd
    cs) (d_C_termEqToREq x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_termEqToREq x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C_termEqToREq x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq" (showCons x2))

nd_C_termEqToREq :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_Tuple2
  (Rewriting.Curry_Term.C_Term t0) (Rewriting.Curry_Term.C_Term t0) -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))
nd_C_termEqToREq x1 x2 s cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> let s6 = s
    in s6 `seq` (let s7 = leftSupply s6
                     s9 = rightSupply s6
                     s0 = leftSupply s7
                     s8 = rightSupply s7
                     s1 = leftSupply s8
                     s2 = rightSupply s8
                     s3 = leftSupply s9
                     s10 = rightSupply s9
                     s4 = leftSupply s10
                     s5 = rightSupply s10
    in s7 `seq` (s9 `seq` (s0 `seq` (s8 `seq` (s1 `seq` (s2 `seq` (s3 `seq`
    (s10 `seq` (s4 `seq` (s5 `seq` (let x5 = nd_C_termToRTerm x1 x3 s0 cd cs
                                        x6 = nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1
                                          x5 s1 cd cs
                                        x7 = nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick
                                          x5 s2 cd cs
                                        x8 = nd_C_termToRTerm x6 x4 s3 cd cs
                                        x9 = nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2
                                          x8 s4 cd cs
                                        x10 = nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick
                                          x8 s5 cd cs
    in Curry_Prelude.OP_Tuple2 x9 (Curry_Prelude.OP_Tuple2 x7 x10))))))))))))
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C_termEqToREq x1 l s
    cd cs) (nd_C_termEqToREq x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_C_termEqToREq x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C_termEqToREq x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq" (showCons x2))

d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)
d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 l cd cs)
    (d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP8#r1" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP8#r1"
    (showCons x1))

nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> IDSupply -> Cover -> ConstStore
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 l s cd cs)
    (nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termEqToREq_dot_uscore_hash_selFP8_hash_r1 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP8#r1" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP8#r1"
    (showCons x1))

d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> Cover -> ConstStore -> C_RTerm t0
d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick l cd cs)
    (d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP9#a'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP9#a'"
    (showCons x1))

nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> IDSupply -> Cover -> ConstStore -> C_RTerm t0
nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick l s cd cs)
    (nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termEqToREq_dot_uscore_hash_selFP9_hash_a_tick e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP9#a'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP9#a'"
    (showCons x1))

d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)
d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 l cd cs)
    (d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP6#r2" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP6#r2"
    (showCons x1))

nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> IDSupply -> Cover -> ConstStore
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 l s cd cs)
    (nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termEqToREq_dot_uscore_hash_selFP6_hash_r2 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP6#r2" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP6#r2"
    (showCons x1))

d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> Cover -> ConstStore -> C_RTerm t0
d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick l cd cs)
    (d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP7#b'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP7#b'"
    (showCons x1))

nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (C_RTerm t0) -> IDSupply -> Cover -> ConstStore -> C_RTerm t0
nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick l s cd cs)
    (nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termEqToREq_dot_uscore_hash_selFP7_hash_b_tick e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termEqToREq._#selFP7#b'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termEqToREq._#selFP7#b'"
    (showCons x1))

d_C_termToRTerm :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Rewriting.Curry_Term.C_Term t0 -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (C_RTerm t0)
d_C_termToRTerm x1 x2 cd cs = case x2 of
  Rewriting.Curry_Term.C_TermVar x3 -> Curry_Prelude.OP_Tuple2
    (Curry_FiniteMap.d_C_addToFM x1 x3 (C_RTermVar x3) cd cs) (C_Ref x3)
  Rewriting.Curry_Term.C_TermCons x4 x5 -> let x6 = Curry_List.d_C_mapAccumL
                                                 (acceptCs id d_C_termToRTerm)
                                                 x1 x5 cd cs
                                               x7 = d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick
                                                 x6 cd cs
                                               x8 = d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick
                                                 x6 cd cs
    in Curry_Prelude.OP_Tuple2 x7 (C_RTermCons x4 x8)
  Rewriting.Curry_Term.Choice_C_Term d i l r -> narrow d i (d_C_termToRTerm x1 l
    cd cs) (d_C_termToRTerm x1 r cd cs)
  Rewriting.Curry_Term.Choices_C_Term d i xs -> narrows cs d i (\z ->
    d_C_termToRTerm x1 z cd cs) xs
  Rewriting.Curry_Term.Guard_C_Term d c e -> guardCons d c (d_C_termToRTerm x1 e
    cd $! addCs c cs)
  Rewriting.Curry_Term.Fail_C_Term d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm" (showCons x2))

nd_C_termToRTerm :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Rewriting.Curry_Term.C_Term t0 -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0)) (C_RTerm t0)
nd_C_termToRTerm x1 x2 s cd cs = case x2 of
  Rewriting.Curry_Term.C_TermVar x3 -> let s0 = s
    in s0 `seq` Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.nd_C_addToFM x1 x3
    (C_RTermVar x3) s0 cd cs) (C_Ref x3)
  Rewriting.Curry_Term.C_TermCons x4 x5 -> let s3 = s
    in s3 `seq` (let s0 = leftSupply s3
                     s4 = rightSupply s3
                     s1 = leftSupply s4
                     s2 = rightSupply s4
    in s0 `seq` (s4 `seq` (s1 `seq` (s2 `seq`
    (let x6 = Curry_List.nd_C_mapAccumL (wrapDX (wrapNX id) (acceptCs id
           nd_C_termToRTerm)) x1 x5 s0 cd cs
         x7 = nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick x6 s1 cd cs
         x8 = nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick x6 s2 cd cs
    in Curry_Prelude.OP_Tuple2 x7 (C_RTermCons x4 x8))))))
  Rewriting.Curry_Term.Choice_C_Term d i l r -> narrow d i (nd_C_termToRTerm x1
    l s cd cs) (nd_C_termToRTerm x1 r s cd cs)
  Rewriting.Curry_Term.Choices_C_Term d i xs -> narrows cs d i (\z ->
    nd_C_termToRTerm x1 z s cd cs) xs
  Rewriting.Curry_Term.Guard_C_Term d c e -> guardCons d c (nd_C_termToRTerm x1
    e s cd $! addCs c cs)
  Rewriting.Curry_Term.Fail_C_Term d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm" (showCons x2))

d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (C_RTerm t0)) -> Cover -> ConstStore
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick l cd cs)
    (d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm._#selFP11#r'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm._#selFP11#r'"
    (showCons x1))

nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (C_RTerm t0)) -> IDSupply -> Cover
  -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick l s cd cs)
    (nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termToRTerm_dot_uscore_hash_selFP11_hash_r_tick e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm._#selFP11#r'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm._#selFP11#r'"
    (showCons x1))

d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (C_RTerm t0)) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (C_RTerm t0)
d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick l cd cs)
    (d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm._#selFP12#l'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm._#selFP12#l'"
    (showCons x1))

nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (C_RTerm t0)) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (C_RTerm t0)
nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick x1 s cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick l s cd cs)
    (nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_termToRTerm_dot_uscore_hash_selFP12_hash_l_tick e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification.termToRTerm._#selFP12#l'" [show x1] info)
  _ -> failCons cd (consFail "Rewriting.Unification.termToRTerm._#selFP12#l'"
    (showCons x1))

d_C_eqsToSubst :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Cover -> ConstStore
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0)
d_C_eqsToSubst x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_List -> Rewriting.Curry_Substitution.d_C_emptySubst cd cs
  Curry_Prelude.OP_Cons x3 x4 -> d_C__case_16 x4 x1 x3 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_eqsToSubst x1 l cd cs)
    (d_C_eqsToSubst x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_eqsToSubst
    x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_eqsToSubst x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Rewriting.Unification.eqsToSubst" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.eqsToSubst" (showCons x2))

nd_C_eqsToSubst :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> IDSupply -> Cover
  -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (Rewriting.Curry_Term.C_Term t0)
nd_C_eqsToSubst x1 x2 s cd cs = case x2 of
  Curry_Prelude.OP_List -> let s0 = s
    in s0 `seq` Rewriting.Curry_Substitution.nd_C_emptySubst s0 cd cs
  Curry_Prelude.OP_Cons x3 x4 -> let s0 = s
    in s0 `seq` nd_C__case_16 x4 x1 x3 s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C_eqsToSubst x1 l s cd
    cs) (nd_C_eqsToSubst x1 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C_eqsToSubst
    x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C_eqsToSubst x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Rewriting.Unification.eqsToSubst" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.eqsToSubst" (showCons x2))

d_C_rTermToTerm :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> Cover -> ConstStore
  -> Rewriting.Curry_Term.C_Term t0
d_C_rTermToTerm x1 x2 cd cs = case x2 of
  C_Ref x3 -> d_C_rTermToTerm x1 (d_C_deref x1 x2 cd cs) cd cs
  C_RTermVar x4 -> Rewriting.Curry_Term.C_TermVar x4
  C_RTermCons x5 x6 -> Rewriting.Curry_Term.C_TermCons x5 (Curry_Prelude.d_C_map
    (d_C_rTermToTerm x1) x6 cd cs)
  Choice_C_RTerm d i l r -> narrow d i (d_C_rTermToTerm x1 l cd cs)
    (d_C_rTermToTerm x1 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C_rTermToTerm x1 z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C_rTermToTerm x1 e cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail
    "Rewriting.Unification.rTermToTerm" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.rTermToTerm" (showCons x2))

nd_C_rTermToTerm :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> IDSupply -> Cover
  -> ConstStore -> Rewriting.Curry_Term.C_Term t0
nd_C_rTermToTerm x1 x2 s cd cs = case x2 of
  C_Ref x3 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C_rTermToTerm x1 (nd_C_deref x1 x2 s0 cd cs) s1 cd
    cs))
  C_RTermVar x4 -> Rewriting.Curry_Term.C_TermVar x4
  C_RTermCons x5 x6 -> let s0 = s
    in s0 `seq` Rewriting.Curry_Term.C_TermCons x5 (Curry_Prelude.nd_C_map
    (wrapNX id (nd_C_rTermToTerm x1)) x6 s0 cd cs)
  Choice_C_RTerm d i l r -> narrow d i (nd_C_rTermToTerm x1 l s cd cs)
    (nd_C_rTermToTerm x1 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C_rTermToTerm x1 z s cd cs)
    xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C_rTermToTerm x1 e s cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail
    "Rewriting.Unification.rTermToTerm" [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.rTermToTerm" (showCons x2))

d_C_deref :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> Cover -> ConstStore
  -> C_RTerm t0
d_C_deref x1 x2 cd cs = case x2 of
  C_Ref x3 -> d_C__case_13 x3 x1 (Curry_FiniteMap.d_C_lookupFM x1 x3 cd cs) cd
    cs
  C_RTermVar x9 -> x2
  C_RTermCons x10 x11 -> x2
  Choice_C_RTerm d i l r -> narrow d i (d_C_deref x1 l cd cs) (d_C_deref x1 r cd
    cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C_deref x1 z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C_deref x1 e cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification.deref"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.deref" (showCons x2))

nd_C_deref :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> IDSupply -> Cover
  -> ConstStore -> C_RTerm t0
nd_C_deref x1 x2 s cd cs = case x2 of
  C_Ref x3 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C__case_13 x3 x1 (Curry_FiniteMap.nd_C_lookupFM x1
    x3 s0 cd cs) s1 cd cs))
  C_RTermVar x9 -> x2
  C_RTermCons x10 x11 -> x2
  Choice_C_RTerm d i l r -> narrow d i (nd_C_deref x1 l s cd cs) (nd_C_deref x1
    r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C_deref x1 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C_deref x1 e s cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification.deref"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "Rewriting.Unification.deref" (showCons x2))

d_C_unify' :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
d_C_unify' x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.OP_List -> Curry_Prelude.C_Right (Curry_Prelude.OP_Tuple2 x1 x2)
  Curry_Prelude.OP_Cons x4 x5 -> d_C__case_11 x5 x1 x2 x4 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_unify' x1 x2 l cd cs)
    (d_C_unify' x1 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_unify' x1 x2
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_unify' x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Rewriting.Unification.unify'" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify'" (showCons x3))

nd_C_unify' :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C_unify' x1 x2 x3 s cd cs = case x3 of
  Curry_Prelude.OP_List -> Curry_Prelude.C_Right (Curry_Prelude.OP_Tuple2 x1 x2)
  Curry_Prelude.OP_Cons x4 x5 -> let s0 = s
    in s0 `seq` nd_C__case_11 x5 x1 x2 x4 s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C_unify' x1 x2 l s cd
    cs) (nd_C_unify' x1 x2 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C_unify' x1
    x2 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C_unify' x1 x2 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Rewriting.Unification.unify'" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Rewriting.Unification.unify'" (showCons x3))

d_C_elim :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Int
  -> C_RTerm t0 -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0)) -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C_elim x1 x2 x3 x4 x5 cd cs = d_C__case_2 x4 x3 x1 x5 x2 (d_C_dependsOn x1
  (C_RTermVar x3) x4 cd cs) cd cs

nd_C_elim :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Int
  -> C_RTerm t0 -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0)) -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C_elim x1 x2 x3 x4 x5 s cd cs = let s2 = s
  in s2 `seq` (let s1 = leftSupply s2
                   s0 = rightSupply s2
  in s1 `seq` (s0 `seq` nd_C__case_2 x4 x3 x1 x5 x2 (nd_C_dependsOn x1
  (C_RTermVar x3) x4 s0 cd cs) s1 cd cs))

d_C_dependsOn :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> C_RTerm t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_dependsOn x1 x2 x3 cd cs = Curry_Prelude.d_OP_amp_amp
  (Curry_Prelude.d_OP_slash_eq x2 x3 cd cs)
  (d_OP_dependsOn_dot_dependsOn_tick_dot_108 x2 x1 x3 cd cs) cd cs

nd_C_dependsOn :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> C_RTerm t0 -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
nd_C_dependsOn x1 x2 x3 s cd cs = let s0 = s
  in s0 `seq` Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_OP_slash_eq x2 x3 cd
  cs) (nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x2 x1 x3 s0 cd cs) cd cs

d_OP_dependsOn_dot_dependsOn_tick_dot_108 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_RTerm t0 -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> C_RTerm t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 x3 cd cs = case x3 of
  C_RTermVar x4 -> Curry_Prelude.d_OP_eq_eq x1 x3 cd cs
  C_RTermCons x5 x6 -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_or cd cs)
    (Curry_Prelude.d_C_map (d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2) x6
    cd cs) cd cs
  C_Ref x7 -> Curry_Prelude.d_OP_eq_eq (d_C_deref x2 x3 cd cs) x1 cd cs
  Choice_C_RTerm d i l r -> narrow d i
    (d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 l cd cs)
    (d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z ->
    d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c
    (d_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 e cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail
    "Rewriting.Unification.dependsOn.dependsOn'.108" [show x1, show x2, show x3]
    info)
  _ -> failCons cd (consFail "Rewriting.Unification.dependsOn.dependsOn'.108"
    (showCons x3))

nd_OP_dependsOn_dot_dependsOn_tick_dot_108 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_RTerm t0 -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> C_RTerm t0 -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Bool
nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 x3 s cd cs = case x3 of
  C_RTermVar x4 -> Curry_Prelude.d_OP_eq_eq x1 x3 cd cs
  C_RTermCons x5 x6 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (wrapDX id
    (Curry_Prelude.d_C_or cd cs)) (Curry_Prelude.nd_C_map (wrapNX id
    (nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2)) x6 s0 cd cs) s1 cd cs))
  C_Ref x7 -> let s0 = s
    in s0 `seq` Curry_Prelude.d_OP_eq_eq (nd_C_deref x2 x3 s0 cd cs) x1 cd cs
  Choice_C_RTerm d i l r -> narrow d i
    (nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 l s cd cs)
    (nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z ->
    nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c
    (nd_OP_dependsOn_dot_dependsOn_tick_dot_108 x1 x2 e s cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail
    "Rewriting.Unification.dependsOn.dependsOn'.108" [show x1, show x2, show x3]
    info)
  _ -> failCons cd (consFail "Rewriting.Unification.dependsOn.dependsOn'.108"
    (showCons x3))

d_C__case_2 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.C_Int -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)) -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_2 x4 x3 x1 x5 x2 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Left
    (Rewriting.Curry_UnificationSpec.C_OccurCheck x3 (d_C_rTermToTerm x1 x4 cd
    cs))
  Curry_Prelude.C_False -> d_C__case_1 x4 x5 x2 x3 x1
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x4 x3 x1 x5 x2
    l cd cs) (d_C__case_2 x4 x3 x1 x5 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x4 x3
    x1 x5 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_2 x4 x3 x1 x5 x2
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_2" [show x4, show x3, show x1, show x5, show x2
    , show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_2" (showCons x6))

nd_C__case_2 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.C_Int -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)) -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_2 x4 x3 x1 x5 x2 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.C_Left
    (Rewriting.Curry_UnificationSpec.C_OccurCheck x3 (nd_C_rTermToTerm x1 x4 s0
    cd cs))
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_1 x4 x5 x2 x3 x1 (Curry_Prelude.d_C_otherwise cd cs)
    s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_2 x4 x3 x1 x5 x2
    l s cd cs) (nd_C__case_2 x4 x3 x1 x5 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_2 x4
    x3 x1 x5 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_2 x4 x3 x1 x5 x2
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_2" [show x4, show x3, show x1, show x5, show x2
    , show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_2" (showCons x6))

d_C__case_1 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0) -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_1 x4 x5 x2 x3 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C__case_0 x5 x2 x3 x1 x4 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x4 x5 x2 x3 x1
    l cd cs) (d_C__case_1 x4 x5 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x4 x5
    x2 x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_1 x4 x5 x2 x3 x1
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_1" [show x4, show x5, show x2, show x3, show x1
    , show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_1" (showCons x6))

nd_C__case_1 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0) -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_1 x4 x5 x2 x3 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C__case_0 x5 x2 x3 x1 x4 s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_1 x4 x5 x2 x3 x1
    l s cd cs) (nd_C__case_1 x4 x5 x2 x3 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_1 x4
    x5 x2 x3 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_1 x4 x5 x2 x3 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_1" [show x4, show x5, show x2, show x3, show x1
    , show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_1" (showCons x6))

d_C__case_0 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Int
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_0 x5 x2 x3 x1 x4 cd cs = case x4 of
  C_RTermVar x6 -> d_C_unify' (Curry_FiniteMap.d_C_addToFM x1 x3 (C_Ref x6) cd
    cs) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (C_RTermVar x3) (C_Ref
    x6)) x2) x5 cd cs
  C_RTermCons x7 x8 -> d_C_unify' (Curry_FiniteMap.d_C_addToFM x1 x3 x4 cd cs)
    (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (C_RTermVar x3) x4) x2) x5
    cd cs
  C_Ref x9 -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Unification.elim") cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_0 x5 x2 x3 x1 l cd cs)
    (d_C__case_0 x5 x2 x3 x1 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_0 x5 x2 x3 x1 z cd
    cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_0 x5 x2 x3 x1 e cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_0"
    [show x5, show x2, show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_0" (showCons x4))

nd_C__case_0 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Int
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C__case_0 x5 x2 x3 x1 x4 s cd cs = case x4 of
  C_RTermVar x6 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C_unify' (Curry_FiniteMap.nd_C_addToFM x1 x3 (C_Ref
    x6) s0 cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (C_RTermVar
    x3) (C_Ref x6)) x2) x5 s1 cd cs))
  C_RTermCons x7 x8 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C_unify' (Curry_FiniteMap.nd_C_addToFM x1 x3 x4 s0
    cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (C_RTermVar x3) x4)
    x2) x5 s1 cd cs))
  C_Ref x9 -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Unification.elim") cd cs
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_0 x5 x2 x3 x1 l s cd cs)
    (nd_C__case_0 x5 x2 x3 x1 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_0 x5 x2 x3 x1 z s
    cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_0 x5 x2 x3 x1 e s cd $! addCs
    c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_0"
    [show x5, show x2, show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_0" (showCons x4))

d_C__case_11 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_Tuple2
  (C_RTerm t0) (C_RTerm t0) -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_11 x5 x1 x2 x4 cd cs = case x4 of
  Curry_Prelude.OP_Tuple2 x6 x7 -> let x8 = Curry_Prelude.OP_Tuple2 x6 x7
    in d_C__case_10 x5 x7 x1 x6 x2 x8 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_11 x5 x1 x2 l
    cd cs) (d_C__case_11 x5 x1 x2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_11
    x5 x1 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_11 x5 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_11" [show x5, show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_11" (showCons x4))

nd_C__case_11 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.OP_Tuple2
  (C_RTerm t0) (C_RTerm t0) -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_11 x5 x1 x2 x4 s cd cs = case x4 of
  Curry_Prelude.OP_Tuple2 x6 x7 -> let s0 = s
    in s0 `seq` (let x8 = Curry_Prelude.OP_Tuple2 x6 x7
    in nd_C__case_10 x5 x7 x1 x6 x2 x8 s0 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_11 x5 x1 x2 l
    s cd cs) (nd_C__case_11 x5 x1 x2 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_11
    x5 x1 x2 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_11 x5 x1 x2 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_11" [show x5, show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_11" (showCons x4))

d_C__case_10 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0) -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
d_C__case_10 x5 x7 x1 x6 x2 x8 cd cs = case x8 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> d_C__case_9 x5 x7 x1 x6 x2 x10 x9 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_10 x5 x7 x1 x6
    x2 l cd cs) (d_C__case_10 x5 x7 x1 x6 x2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_10
    x5 x7 x1 x6 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_10 x5 x7 x1 x6
    x2 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_10" [show x5, show x7, show x1, show x6, show
    x2, show x8] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_10" (showCons x8))

nd_C__case_10 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C__case_10 x5 x7 x1 x6 x2 x8 s cd cs = case x8 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> let s0 = s
    in s0 `seq` nd_C__case_9 x5 x7 x1 x6 x2 x10 x9 s0 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_10 x5 x7 x1
    x6 x2 l s cd cs) (nd_C__case_10 x5 x7 x1 x6 x2 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_10
    x5 x7 x1 x6 x2 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_10 x5 x7 x1
    x6 x2 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_10" [show x5, show x7, show x1, show x6, show
    x2, show x8] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_10" (showCons x8))

d_C__case_9 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> C_RTerm t0 -> C_RTerm t0 -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_9 x5 x7 x1 x6 x2 x10 x9 cd cs = case x9 of
  C_RTermVar x11 -> d_C__case_8 x5 x7 x1 x6 x2 x11 x10 cd cs
  C_RTermCons x16 x17 -> d_C__case_5 x5 x7 x1 x6 x2 x16 x17 x10 cd cs
  C_Ref x22 -> d_C_unify' x1 x2 (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
    (d_C_deref x1 x6 cd cs) (d_C_deref x1 x7 cd cs)) x5) cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_9 x5 x7 x1 x6 x2 x10 l cd cs)
    (d_C__case_9 x5 x7 x1 x6 x2 x10 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_9 x5 x7 x1 x6 x2 x10
    z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_9 x5 x7 x1 x6 x2 x10 e cd $!
    addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_9"
    [show x5, show x7, show x1, show x6, show x2, show x10, show x9] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_9" (showCons x9))

nd_C__case_9 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> C_RTerm t0 -> C_RTerm t0 -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_9 x5 x7 x1 x6 x2 x10 x9 s cd cs = case x9 of
  C_RTermVar x11 -> let s0 = s
    in s0 `seq` nd_C__case_8 x5 x7 x1 x6 x2 x11 x10 s0 cd cs
  C_RTermCons x16 x17 -> let s0 = s
    in s0 `seq` nd_C__case_5 x5 x7 x1 x6 x2 x16 x17 x10 s0 cd cs
  C_Ref x22 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (let s0 = leftSupply s2
         s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x6 s0 cd cs)
    (nd_C_deref x1 x7 s1 cd cs))) x5) s3 cd cs))
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_9 x5 x7 x1 x6 x2 x10 l s cd
    cs) (nd_C__case_9 x5 x7 x1 x6 x2 x10 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_9 x5 x7 x1 x6 x2
    x10 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_9 x5 x7 x1 x6 x2 x10 e s
    cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_9"
    [show x5, show x7, show x1, show x6, show x2, show x10, show x9] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_9" (showCons x9))

d_C__case_5 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> t0 -> Curry_Prelude.OP_List (C_RTerm t0) -> C_RTerm t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_5 x5 x7 x1 x6 x2 x16 x17 x10 cd cs = case x10 of
  C_RTermVar x18 -> d_C_elim x1 x2 x18 x6 x5 cd cs
  C_RTermCons x19 x20 -> d_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17
    (Curry_Prelude.d_OP_eq_eq x16 x19 cd cs) cd cs
  C_Ref x21 -> d_C_unify' x1 x2 (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
    (d_C_deref x1 x6 cd cs) (d_C_deref x1 x7 cd cs)) x5) cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_5 x5 x7 x1 x6 x2 x16 x17 l cd
    cs) (d_C__case_5 x5 x7 x1 x6 x2 x16 x17 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_5 x5 x7 x1 x6 x2 x16
    x17 z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_5 x5 x7 x1 x6 x2 x16 x17 e
    cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_5"
    [show x5, show x7, show x1, show x6, show x2, show x16, show x17, show x10]
    info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_5" (showCons x10))

nd_C__case_5 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> t0 -> Curry_Prelude.OP_List (C_RTerm t0) -> C_RTerm t0 -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C__case_5 x5 x7 x1 x6 x2 x16 x17 x10 s cd cs = case x10 of
  C_RTermVar x18 -> let s0 = s in s0 `seq` nd_C_elim x1 x2 x18 x6 x5 s0 cd cs
  C_RTermCons x19 x20 -> let s0 = s
    in s0 `seq` nd_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17
    (Curry_Prelude.d_OP_eq_eq x16 x19 cd cs) s0 cd cs
  C_Ref x21 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (let s0 = leftSupply s2
         s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x6 s0 cd cs)
    (nd_C_deref x1 x7 s1 cd cs))) x5) s3 cd cs))
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_5 x5 x7 x1 x6 x2 x16 x17 l s
    cd cs) (nd_C__case_5 x5 x7 x1 x6 x2 x16 x17 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_5 x5 x7 x1 x6 x2
    x16 x17 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_5 x5 x7 x1 x6 x2 x16 x17 e s
    cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_5"
    [show x5, show x7, show x1, show x6, show x2, show x16, show x17, show x10]
    info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_5" (showCons x10))

d_C__case_4 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> C_RTerm t0 -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> C_RTerm t0 -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0)) -> Curry_Prelude.OP_List (C_RTerm t0) -> Curry_Prelude.OP_List
  (C_RTerm t0) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
d_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17 x21 cd cs = case x21 of
  Curry_Prelude.C_True -> d_C_unify' x1 x2 (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_zip x17 x20 cd cs) x5 cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_3 x5 x7 x1 x6 x2
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x19 x16 x5 x7
    x1 x6 x2 x20 x17 l cd cs) (d_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17 r cd
    cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x19
    x16 x5 x7 x1 x6 x2 x20 x17 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_4 x19 x16 x5 x7
    x1 x6 x2 x20 x17 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_4" [show x19, show x16, show x5, show x7, show
    x1, show x6, show x2, show x20, show x17, show x21] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_4" (showCons x21))

nd_C__case_4 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> C_RTerm t0 -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> C_RTerm t0 -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0)) -> Curry_Prelude.OP_List (C_RTerm t0) -> Curry_Prelude.OP_List
  (C_RTerm t0) -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17 x21 s cd cs = case x21 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C_unify' x1 x2 (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_zip x17 x20 cd cs) x5 cd cs) s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_3 x5 x7 x1 x6 x2 (Curry_Prelude.d_C_otherwise cd cs)
    s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_4 x19 x16 x5 x7
    x1 x6 x2 x20 x17 l s cd cs) (nd_C__case_4 x19 x16 x5 x7 x1 x6 x2 x20 x17 r s
    cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_4 x19
    x16 x5 x7 x1 x6 x2 x20 x17 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_4 x19 x16 x5 x7
    x1 x6 x2 x20 x17 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_4" [show x19, show x16, show x5, show x7, show
    x1, show x6, show x2, show x20, show x17, show x21] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_4" (showCons x21))

d_C__case_3 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_3 x5 x7 x1 x6 x2 x8 cd cs = case x8 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_dollar (acceptCs id
    Curry_Prelude.C_Left) (Rewriting.Curry_UnificationSpec.C_Clash
    (d_C_rTermToTerm x1 x6 cd cs) (d_C_rTermToTerm x1 x7 cd cs)) cd cs
  Curry_Prelude.C_False -> d_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Tuple2 (d_C_deref x1 x6 cd cs) (d_C_deref x1 x7 cd cs))
    x5) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x5 x7 x1 x6 x2
    l cd cs) (d_C__case_3 x5 x7 x1 x6 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x5 x7
    x1 x6 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_3 x5 x7 x1 x6 x2
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_3" [show x5, show x7, show x1, show x6, show x2
    , show x8] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_3" (showCons x8))

nd_C__case_3 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_3 x5 x7 x1 x6 x2 x8 s cd cs = case x8 of
  Curry_Prelude.C_True -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id (acceptCs id
    Curry_Prelude.C_Left)) (let s0 = leftSupply s2
                                s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Rewriting.Curry_UnificationSpec.C_Clash
    (nd_C_rTermToTerm x1 x6 s0 cd cs) (nd_C_rTermToTerm x1 x7 s1 cd cs))) s3 cd
    cs))
  Curry_Prelude.C_False -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (let s0 = leftSupply s2
         s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x6 s0 cd cs)
    (nd_C_deref x1 x7 s1 cd cs))) x5) s3 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_3 x5 x7 x1 x6 x2
    l s cd cs) (nd_C__case_3 x5 x7 x1 x6 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_3 x5
    x7 x1 x6 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_3 x5 x7 x1 x6 x2
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_3" [show x5, show x7, show x1, show x6, show x2
    , show x8] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_3" (showCons x8))

d_C__case_8 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> C_RTerm t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
d_C__case_8 x5 x7 x1 x6 x2 x11 x10 cd cs = case x10 of
  C_RTermCons x12 x13 -> d_C_elim x1 x2 x11 x7 x5 cd cs
  C_RTermVar x14 -> d_C__case_7 x14 x11 x5 x7 x1 x6 x2 (Curry_Prelude.d_OP_eq_eq
    x11 x14 cd cs) cd cs
  C_Ref x15 -> d_C_unify' x1 x2 (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
    (d_C_deref x1 x6 cd cs) (d_C_deref x1 x7 cd cs)) x5) cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_8 x5 x7 x1 x6 x2 x11 l cd cs)
    (d_C__case_8 x5 x7 x1 x6 x2 x11 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_8 x5 x7 x1 x6 x2 x11
    z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_8 x5 x7 x1 x6 x2 x11 e cd $!
    addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_8"
    [show x5, show x7, show x1, show x6, show x2, show x11, show x10] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_8" (showCons x10))

nd_C__case_8 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> C_RTerm t0 -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
nd_C__case_8 x5 x7 x1 x6 x2 x11 x10 s cd cs = case x10 of
  C_RTermCons x12 x13 -> let s0 = s
    in s0 `seq` nd_C_elim x1 x2 x11 x7 x5 s0 cd cs
  C_RTermVar x14 -> let s0 = s
    in s0 `seq` nd_C__case_7 x14 x11 x5 x7 x1 x6 x2 (Curry_Prelude.d_OP_eq_eq
    x11 x14 cd cs) s0 cd cs
  C_Ref x15 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (let s0 = leftSupply s2
         s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x6 s0 cd cs)
    (nd_C_deref x1 x7 s1 cd cs))) x5) s3 cd cs))
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_8 x5 x7 x1 x6 x2 x11 l s cd
    cs) (nd_C__case_8 x5 x7 x1 x6 x2 x11 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_8 x5 x7 x1 x6 x2
    x11 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_8 x5 x7 x1 x6 x2 x11 e s
    cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_8"
    [show x5, show x7, show x1, show x6, show x2, show x11, show x10] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_8" (showCons x10))

d_C__case_7 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.C_Int
  -> Curry_Prelude.C_Int -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0 -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
d_C__case_7 x14 x11 x5 x7 x1 x6 x2 x15 cd cs = case x15 of
  Curry_Prelude.C_True -> d_C_unify' x1 x2 x5 cd cs
  Curry_Prelude.C_False -> d_C__case_6 x5 x7 x1 x6 x2 x11
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_7 x14 x11 x5 x7
    x1 x6 x2 l cd cs) (d_C__case_7 x14 x11 x5 x7 x1 x6 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_7 x14
    x11 x5 x7 x1 x6 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_7 x14 x11 x5 x7
    x1 x6 x2 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_7" [show x14, show x11, show x5, show x7, show
    x1, show x6, show x2, show x15] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_7" (showCons x15))

nd_C__case_7 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.C_Int
  -> Curry_Prelude.C_Int -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0 -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C__case_7 x14 x11 x5 x7 x1 x6 x2 x15 s cd cs = case x15 of
  Curry_Prelude.C_True -> let s0 = s in s0 `seq` nd_C_unify' x1 x2 x5 s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_6 x5 x7 x1 x6 x2 x11 (Curry_Prelude.d_C_otherwise cd
    cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_7 x14 x11 x5 x7
    x1 x6 x2 l s cd cs) (nd_C__case_7 x14 x11 x5 x7 x1 x6 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_7 x14
    x11 x5 x7 x1 x6 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_7 x14 x11 x5 x7
    x1 x6 x2 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_7" [show x14, show x11, show x5, show x7, show
    x1, show x6, show x2, show x15] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_7" (showCons x15))

d_C__case_6 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (C_RTerm t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0))))
d_C__case_6 x5 x7 x1 x6 x2 x11 x12 cd cs = case x12 of
  Curry_Prelude.C_True -> d_C_elim x1 x2 x11 x7 x5 cd cs
  Curry_Prelude.C_False -> d_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Tuple2 (d_C_deref x1 x6 cd cs) (d_C_deref x1 x7 cd cs))
    x5) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_6 x5 x7 x1 x6 x2
    x11 l cd cs) (d_C__case_6 x5 x7 x1 x6 x2 x11 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_6 x5 x7
    x1 x6 x2 x11 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_6 x5 x7 x1 x6 x2
    x11 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_6" [show x5, show x7, show x1, show x6, show x2
    , show x11, show x12] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_6" (showCons x12))

nd_C__case_6 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> C_RTerm t0
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0))))
nd_C__case_6 x5 x7 x1 x6 x2 x11 x12 s cd cs = case x12 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C_elim x1 x2 x11 x7 x5 s0 cd cs
  Curry_Prelude.C_False -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C_unify' x1 x2 (Curry_Prelude.OP_Cons
    (let s0 = leftSupply s2
         s1 = rightSupply s2
    in s0 `seq` (s1 `seq` Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x6 s0 cd cs)
    (nd_C_deref x1 x7 s1 cd cs))) x5) s3 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_6 x5 x7 x1 x6 x2
    x11 l s cd cs) (nd_C__case_6 x5 x7 x1 x6 x2 x11 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_6 x5
    x7 x1 x6 x2 x11 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_6 x5 x7 x1 x6 x2
    x11 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Rewriting.Unification._case_6" [show x5, show x7, show x1, show x6, show x2
    , show x11, show x12] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_6" (showCons x12))

d_C__case_13 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.C_Int
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> Curry_Prelude.C_Maybe (C_RTerm t0) -> Cover -> ConstStore -> C_RTerm t0
d_C__case_13 x3 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_Nothing -> Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_error
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Unification.deref: ") (Curry_Prelude.d_C_show x3 cd cs) cd cs) cd cs
  Curry_Prelude.C_Just x4 -> d_C__case_12 x1 x4 cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i (d_C__case_13 x3 x1 l cd
    cs) (d_C__case_13 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z -> d_C__case_13 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c (d_C__case_13 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail
    "Rewriting.Unification._case_13" [show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_13" (showCons x5))

nd_C__case_13 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.C_Int
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)
  -> Curry_Prelude.C_Maybe (C_RTerm t0) -> IDSupply -> Cover -> ConstStore
  -> C_RTerm t0
nd_C__case_13 x3 x1 x5 s cd cs = case x5 of
  Curry_Prelude.C_Nothing -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id Curry_Prelude.d_C_error)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Unification.deref: ") (Curry_Prelude.d_C_show x3 cd cs) cd cs) s0 cd cs
  Curry_Prelude.C_Just x4 -> let s0 = s in s0 `seq` nd_C__case_12 x1 x4 s0 cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i (nd_C__case_13 x3 x1 l s cd
    cs) (nd_C__case_13 x3 x1 r s cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z -> nd_C__case_13 x3
    x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c (nd_C__case_13 x3 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail
    "Rewriting.Unification._case_13" [show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_13" (showCons x5))

d_C__case_12 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> Cover -> ConstStore
  -> C_RTerm t0
d_C__case_12 x1 x4 cd cs = case x4 of
  C_RTermVar x5 -> x4
  C_RTermCons x6 x7 -> x4
  C_Ref x8 -> d_C_deref x1 x4 cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_12 x1 l cd cs) (d_C__case_12
    x1 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_12 x1 z cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_12 x1 e cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_12"
    [show x1, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_12" (showCons x4))

nd_C__case_12 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> IDSupply -> Cover
  -> ConstStore -> C_RTerm t0
nd_C__case_12 x1 x4 s cd cs = case x4 of
  C_RTermVar x5 -> x4
  C_RTermCons x6 x7 -> x4
  C_Ref x8 -> let s0 = s in s0 `seq` nd_C_deref x1 x4 s0 cd cs
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_12 x1 l s cd cs)
    (nd_C__case_12 x1 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_12 x1 z s cd cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_12 x1 e s cd $! addCs c cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_12"
    [show x1, show x4] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_12" (showCons x4))

d_C__case_16 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0) -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0)
d_C__case_16 x4 x1 x3 cd cs = case x3 of
  Curry_Prelude.OP_Tuple2 x5 x6 -> d_C__case_15 x6 x4 x1 x5 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_16 x4 x1 l cd
    cs) (d_C__case_16 x4 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_16
    x4 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_16 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_16" [show x4, show x1, show x3] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_16" (showCons x3))

nd_C__case_16 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.OP_Tuple2 (C_RTerm t0)
  (C_RTerm t0) -> IDSupply -> Cover -> ConstStore -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0)
nd_C__case_16 x4 x1 x3 s cd cs = case x3 of
  Curry_Prelude.OP_Tuple2 x5 x6 -> let s0 = s
    in s0 `seq` nd_C__case_15 x6 x4 x1 x5 s0 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_16 x4 x1 l s
    cd cs) (nd_C__case_16 x4 x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_16
    x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_16 x4 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_16" [show x4, show x1, show x3] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_16" (showCons x3))

d_C__case_15 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> Cover -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (Rewriting.Curry_Term.C_Term t0)
d_C__case_15 x6 x4 x1 x5 cd cs = case x5 of
  C_Ref x7 -> d_C_eqsToSubst x1 (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
    (d_C_deref x1 x5 cd cs) x6) x4) cd cs
  C_RTermVar x8 -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Rewriting.Curry_Substitution.d_C_extendSubst cd
    cs) (d_C_eqsToSubst x1 x4 cd cs) cd cs) x8 cd cs) (d_C_rTermToTerm x1 x6 cd
    cs) cd cs
  C_RTermCons x9 x10 -> d_C__case_14 x4 x1 x5 x6 cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_15 x6 x4 x1 l cd cs)
    (d_C__case_15 x6 x4 x1 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_15 x6 x4 x1 z cd cs)
    xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_15 x6 x4 x1 e cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_15"
    [show x6, show x4, show x1, show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_15" (showCons x5))

nd_C__case_15 :: forall t0 . (Curry_Prelude.Curry t0) => C_RTerm t0
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))
  -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0
  -> IDSupply -> Cover -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (Rewriting.Curry_Term.C_Term t0)
nd_C__case_15 x6 x4 x1 x5 s cd cs = case x5 of
  C_Ref x7 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C_eqsToSubst x1 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Tuple2 (nd_C_deref x1 x5 s0 cd cs) x6) x4) s1 cd cs))
  C_RTermVar x8 -> let s9 = s
    in s9 `seq` (let s8 = leftSupply s9
                     s10 = rightSupply s9
                     s6 = leftSupply s10
                     s7 = rightSupply s10
    in s8 `seq` (s10 `seq` (s6 `seq` (s7 `seq` Curry_Prelude.nd_C_apply
    (let s5 = leftSupply s6
         s3 = rightSupply s6
    in s5 `seq` (s3 `seq` Curry_Prelude.nd_C_apply (let s2 = leftSupply s3
                                                        s4 = rightSupply s3
                                                        s0 = leftSupply s4
                                                        s1 = rightSupply s4
    in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_C_apply
    (Rewriting.Curry_Substitution.nd_C_extendSubst s0 cd cs) (nd_C_eqsToSubst x1
    x4 s1 cd cs) s2 cd cs)))) x8 s5 cd cs)) (nd_C_rTermToTerm x1 x6 s7 cd cs) s8
    cd cs))))
  C_RTermCons x9 x10 -> let s0 = s
    in s0 `seq` nd_C__case_14 x4 x1 x5 x6 s0 cd cs
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_15 x6 x4 x1 l s cd cs)
    (nd_C__case_15 x6 x4 x1 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_15 x6 x4 x1 z s cd
    cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_15 x6 x4 x1 e s cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_15"
    [show x6, show x4, show x1, show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_15" (showCons x5))

d_C__case_14 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> C_RTerm t0 -> Cover
  -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (Rewriting.Curry_Term.C_Term t0)
d_C__case_14 x4 x1 x5 x6 cd cs = case x6 of
  C_RTermVar x11 -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Rewriting.Curry_Substitution.d_C_extendSubst cd
    cs) (d_C_eqsToSubst x1 x4 cd cs) cd cs) x11 cd cs) (d_C_rTermToTerm x1 x5 cd
    cs) cd cs
  C_Ref x12 -> d_C_eqsToSubst x1 (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
    x5 (d_C_deref x1 x6 cd cs)) x4) cd cs
  C_RTermCons x13 x14 -> d_C_eqsToSubst x1 x4 cd cs
  Choice_C_RTerm d i l r -> narrow d i (d_C__case_14 x4 x1 x5 l cd cs)
    (d_C__case_14 x4 x1 x5 r cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> d_C__case_14 x4 x1 x5 z cd cs)
    xs
  Guard_C_RTerm d c e -> guardCons d c (d_C__case_14 x4 x1 x5 e cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_14"
    [show x4, show x1, show x5, show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_14" (showCons x6))

nd_C__case_14 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> C_RTerm t0 -> C_RTerm t0 -> IDSupply
  -> Cover -> ConstStore -> Curry_FiniteMap.C_FM Curry_Prelude.C_Int
  (Rewriting.Curry_Term.C_Term t0)
nd_C__case_14 x4 x1 x5 x6 s cd cs = case x6 of
  C_RTermVar x11 -> let s9 = s
    in s9 `seq` (let s8 = leftSupply s9
                     s10 = rightSupply s9
                     s6 = leftSupply s10
                     s7 = rightSupply s10
    in s8 `seq` (s10 `seq` (s6 `seq` (s7 `seq` Curry_Prelude.nd_C_apply
    (let s5 = leftSupply s6
         s3 = rightSupply s6
    in s5 `seq` (s3 `seq` Curry_Prelude.nd_C_apply (let s2 = leftSupply s3
                                                        s4 = rightSupply s3
                                                        s0 = leftSupply s4
                                                        s1 = rightSupply s4
    in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_C_apply
    (Rewriting.Curry_Substitution.nd_C_extendSubst s0 cd cs) (nd_C_eqsToSubst x1
    x4 s1 cd cs) s2 cd cs)))) x11 s5 cd cs)) (nd_C_rTermToTerm x1 x5 s7 cd cs)
    s8 cd cs))))
  C_Ref x12 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C_eqsToSubst x1 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Tuple2 x5 (nd_C_deref x1 x6 s0 cd cs)) x4) s1 cd cs))
  C_RTermCons x13 x14 -> let s0 = s in s0 `seq` nd_C_eqsToSubst x1 x4 s0 cd cs
  Choice_C_RTerm d i l r -> narrow d i (nd_C__case_14 x4 x1 x5 l s cd cs)
    (nd_C__case_14 x4 x1 x5 r s cd cs)
  Choices_C_RTerm d i xs -> narrows cs d i (\z -> nd_C__case_14 x4 x1 x5 z s cd
    cs) xs
  Guard_C_RTerm d c e -> guardCons d c (nd_C__case_14 x4 x1 x5 e s cd $! addCs c
    cs)
  Fail_C_RTerm d info -> failCons d (traceFail "Rewriting.Unification._case_14"
    [show x4, show x1, show x5, show x6] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_14" (showCons x6))

d_C__case_18 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)))) -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0) (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0))
d_C__case_18 x4 x3 x9 cd cs = case x9 of
  Curry_Prelude.C_Right x5 -> d_C__case_17 x5 cd cs
  Curry_Prelude.C_Left x8 -> Curry_Prelude.C_Left x8
  Curry_Prelude.Choice_C_Either d i l r -> narrow d i (d_C__case_18 x4 x3 l cd
    cs) (d_C__case_18 x4 x3 r cd cs)
  Curry_Prelude.Choices_C_Either d i xs -> narrows cs d i (\z -> d_C__case_18 x4
    x3 z cd cs) xs
  Curry_Prelude.Guard_C_Either d c e -> guardCons d c (d_C__case_18 x4 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Either d info -> failCons d (traceFail
    "Rewriting.Unification._case_18" [show x4, show x3, show x9] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_18" (showCons x9))

nd_C__case_18 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0)) -> Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (C_RTerm t0) -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0)
  (Curry_Prelude.OP_Tuple2 (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm
  t0)) (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm
  t0)))) -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0) (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0))
nd_C__case_18 x4 x3 x9 s cd cs = case x9 of
  Curry_Prelude.C_Right x5 -> let s0 = s in s0 `seq` nd_C__case_17 x5 s0 cd cs
  Curry_Prelude.C_Left x8 -> Curry_Prelude.C_Left x8
  Curry_Prelude.Choice_C_Either d i l r -> narrow d i (nd_C__case_18 x4 x3 l s
    cd cs) (nd_C__case_18 x4 x3 r s cd cs)
  Curry_Prelude.Choices_C_Either d i xs -> narrows cs d i (\z -> nd_C__case_18
    x4 x3 z s cd cs) xs
  Curry_Prelude.Guard_C_Either d c e -> guardCons d c (nd_C__case_18 x4 x3 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Either d info -> failCons d (traceFail
    "Rewriting.Unification._case_18" [show x4, show x3, show x9] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_18" (showCons x9))

d_C__case_17 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_Tuple2
  (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))) -> Cover -> ConstStore
  -> Curry_Prelude.C_Either (Rewriting.Curry_UnificationSpec.C_UnificationError
  t0) (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term
  t0))
d_C__case_17 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x6 x7 -> Curry_Prelude.C_Right (d_C_eqsToSubst x6 x7
    cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_17 l cd cs)
    (d_C__case_17 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_17 z
    cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_17 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_17" [show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_17" (showCons x5))

nd_C__case_17 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_Tuple2
  (Curry_FiniteMap.C_FM Curry_Prelude.C_Int (C_RTerm t0)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (C_RTerm t0) (C_RTerm t0))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Either
  (Rewriting.Curry_UnificationSpec.C_UnificationError t0) (Curry_FiniteMap.C_FM
  Curry_Prelude.C_Int (Rewriting.Curry_Term.C_Term t0))
nd_C__case_17 x5 s cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x6 x7 -> let s0 = s
    in s0 `seq` Curry_Prelude.C_Right (nd_C_eqsToSubst x6 x7 s0 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_17 l s cd cs)
    (nd_C__case_17 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_17
    z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_17 e s cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Rewriting.Unification._case_17" [show x5] info)
  _ -> failCons cd (consFail "Rewriting.Unification._case_17" (showCons x5))

